Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_app.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_app.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_app.py	(revision 11949)
@@ -22,8 +22,8 @@
 from zope.component.hooks import setSite
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.kofa.app import University
-from waeup.kofa.interfaces import (
+from waeup.ikoba.app import University
+from waeup.ikoba.interfaces import (
     IUniversity, IJobManager, VIRT_JOBS_CONTAINER_NAME)
-from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+from waeup.ikoba.testing import FunctionalLayer, FunctionalTestCase
 
 class UniversityTests(FunctionalTestCase):
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_authentication.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_authentication.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_authentication.py	(revision 11949)
@@ -27,10 +27,10 @@
 from zope.pluggableauth.interfaces import IAuthenticatorPlugin
 from zope.securitypolicy.interfaces import IPrincipalRoleManager
-from waeup.kofa.testing import FunctionalTestCase, FunctionalLayer
-from waeup.kofa.authentication import (
-    UserAuthenticatorPlugin, Account, KofaPrincipalInfo, FailedLoginInfo,
+from waeup.ikoba.testing import FunctionalTestCase, FunctionalLayer
+from waeup.ikoba.authentication import (
+    UserAuthenticatorPlugin, Account, IkobaPrincipalInfo, FailedLoginInfo,
     get_principal_role_manager, UsersPlugin,)
-from waeup.kofa.interfaces import (
-    IUserAccount, IFailedLoginInfo, IKofaPrincipalInfo, IKofaPluggable)
+from waeup.ikoba.interfaces import (
+    IUserAccount, IFailedLoginInfo, IIkobaPrincipalInfo, IIkobaPluggable)
 
 class FakeSite(grok.Site, grok.Container):
@@ -74,5 +74,5 @@
         result2 = plugin.authenticateCredentials(
             dict(login='bob', password='nonsense'))
-        self.assertTrue(isinstance(result1, KofaPrincipalInfo))
+        self.assertTrue(isinstance(result1, IkobaPrincipalInfo))
         self.assertTrue(result2 is None)
         return
@@ -83,5 +83,5 @@
         result1 = plugin.principalInfo('bob')
         result2 = plugin.principalInfo('manfred')
-        self.assertTrue(isinstance(result1, KofaPrincipalInfo))
+        self.assertTrue(isinstance(result1, IkobaPrincipalInfo))
         self.assertTrue(result2 is None)
         return
@@ -117,5 +117,5 @@
         # disabled)
         results = []
-        succ_principal = KofaPrincipalInfo(
+        succ_principal = IkobaPrincipalInfo(
             id='bob',
             title='bob',
@@ -133,8 +133,8 @@
         return
 
-class KofaPrincipalInfoTests(unittest.TestCase):
+class IkobaPrincipalInfoTests(unittest.TestCase):
 
     def create_info(self):
-        return KofaPrincipalInfo(
+        return IkobaPrincipalInfo(
             id='bob',
             title='bob',
@@ -148,6 +148,6 @@
         # make sure we implement the promised interfaces
         info = self.create_info()
-        verifyClass(IKofaPrincipalInfo, KofaPrincipalInfo)
-        verifyObject(IKofaPrincipalInfo, info)
+        verifyClass(IIkobaPrincipalInfo, IkobaPrincipalInfo)
+        verifyObject(IIkobaPrincipalInfo, info)
         return
 
@@ -305,6 +305,6 @@
         # make sure we implement the promised interfaces
         plugin = UsersPlugin()
-        verifyClass(IKofaPluggable, UsersPlugin)
-        verifyObject(IKofaPluggable, plugin)
+        verifyClass(IIkobaPluggable, UsersPlugin)
+        verifyObject(IIkobaPluggable, plugin)
         return
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_beaker.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_beaker.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_beaker.py	(revision 11949)
@@ -2,5 +2,5 @@
 from zope.publisher.browser import TestRequest
 from zope.session.interfaces import ISession
-from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+from waeup.ikoba.testing import FunctionalLayer, FunctionalTestCase
 
 class BeakerTests(FunctionalTestCase):
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_catalog.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_catalog.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_catalog.py	(revision 11949)
@@ -26,7 +26,7 @@
 from zope.interface import Interface, Attribute
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
-from waeup.kofa.catalog import FilteredQueryBase, FilteredCatalogQueryBase
-from waeup.kofa.interfaces import IFilteredQuery, IFilteredCatalogQuery
+from waeup.ikoba.testing import FunctionalLayer, FunctionalTestCase
+from waeup.ikoba.catalog import FilteredQueryBase, FilteredCatalogQueryBase
+from waeup.ikoba.interfaces import IFilteredQuery, IFilteredCatalogQuery
 
 class FilteredQueryBaseTests(unittest.TestCase):
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_configuration.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_configuration.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_configuration.py	(revision 11949)
@@ -20,8 +20,8 @@
 from zope.component.interfaces import IFactory
 from zope.interface import verify
-from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
-from waeup.kofa.configuration import (
+from waeup.ikoba.testing import FunctionalLayer, FunctionalTestCase
+from waeup.ikoba.configuration import (
     ConfigurationContainer, SessionConfiguration, SessionConfigurationFactory)
-from waeup.kofa.interfaces import(
+from waeup.ikoba.interfaces import(
     IConfigurationContainer, ISessionConfiguration, ISessionConfigurationAdd)
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_datacenter.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_datacenter.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_datacenter.py	(revision 11949)
@@ -10,6 +10,6 @@
 from zope.component import getUtility, getGlobalSiteManager
 from zope.interface.verify import verifyObject, verifyClass
-from waeup.kofa.datacenter import DataCenter
-from waeup.kofa.interfaces import (
+from waeup.ikoba.datacenter import DataCenter
+from waeup.ikoba.interfaces import (
     IDataCenter, IDataCenterConfig, IExportJobContainer)
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_fees.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_fees.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_fees.py	(revision 11949)
@@ -2,6 +2,6 @@
 import unittest
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.kofa.fees import IFeeTable
-from waeup.kofa.fees import FeeTable, nested_list, nested_tuple
+from waeup.ikoba.fees import IFeeTable
+from waeup.ikoba.fees import FeeTable, nested_list, nested_tuple
 
 SAMPLE_PARAMS = (('locals', 'non-locals'), ('art', 'science'),
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_imagestorage.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_imagestorage.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_imagestorage.py	(revision 11949)
@@ -27,10 +27,10 @@
 from zope.component.hooks import setSite
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.kofa.app import University
-from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
-from waeup.kofa.imagestorage import (
+from waeup.ikoba.app import University
+from waeup.ikoba.testing import FunctionalLayer, FunctionalTestCase
+from waeup.ikoba.imagestorage import (
     FileStoreNameChooser, ExtFileStore, DefaultFileStoreHandler,
     DefaultStorage)
-from waeup.kofa.interfaces import (
+from waeup.ikoba.interfaces import (
     IFileStoreNameChooser, IExtFileStore, IFileStoreHandler,)
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_interfaces.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_interfaces.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_interfaces.py	(revision 11949)
@@ -21,6 +21,6 @@
 import grok
 import unittest
-from waeup.kofa.interfaces import DuplicationError, RoleSource, check_email
-from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+from waeup.ikoba.interfaces import DuplicationError, RoleSource, check_email
+from waeup.ikoba.testing import FunctionalLayer, FunctionalTestCase
 
 class RegExTests(unittest.TestCase):
@@ -87,10 +87,10 @@
         # Register a role not visible to waeup portal as its name does
         # not start with 'waeup.'
-        class NonKofaRole(grok.Role):
+        class NonIkobaRole(grok.Role):
             grok.name('nonwaeup.testrole')
             grok.title('Role not suitable for waeup')
             grok.permissions('waeup.Public')
         grok.testing.grok_component('SomeRole', SomeRole)
-        grok.testing.grok_component('NonKofaRole', NonKofaRole)
+        grok.testing.grok_component('NonIkobaRole', NonIkobaRole)
         return
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_maintenance.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_maintenance.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_maintenance.py	(revision 11949)
@@ -9,7 +9,7 @@
 from zope.component.hooks import setSite
 from zope.interface import Interface, implements
-from waeup.kofa.app import University
-from waeup.kofa.maintenance import update_catalog
-from waeup.kofa.testing import FunctionalTestCase, FunctionalLayer
+from waeup.ikoba.app import University
+from waeup.ikoba.maintenance import update_catalog
+from waeup.ikoba.testing import FunctionalTestCase, FunctionalLayer
 
 class ISampleContent(Interface):
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_objecthistory.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_objecthistory.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_objecthistory.py	(revision 11949)
@@ -25,11 +25,11 @@
 from zope.security.management import newInteraction, endInteraction
 from zope.security.testing import Principal, Participation
-from waeup.kofa.app import University
-from waeup.kofa.interfaces import IObjectHistory, IKofaObject
-from waeup.kofa.testing import FunctionalTestCase, FunctionalLayer
-from waeup.kofa.objecthistory import ObjectHistory
+from waeup.ikoba.app import University
+from waeup.ikoba.interfaces import IObjectHistory, IIkobaObject
+from waeup.ikoba.testing import FunctionalTestCase, FunctionalLayer
+from waeup.ikoba.objecthistory import ObjectHistory
 
 class SampleObject(grok.Model):
-    grok.implements(IKofaObject)
+    grok.implements(IIkobaObject)
     pass
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_reports.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_reports.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_reports.py	(revision 11949)
@@ -11,13 +11,13 @@
 from zope.component.hooks import setSite
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.kofa.interfaces import IJobManager, IKofaPluggable
-from waeup.kofa.reports import (
+from waeup.ikoba.interfaces import IJobManager, IIkobaPluggable
+from waeup.ikoba.reports import (
     IReport, IReportGenerator, IReportJob, IReportJobContainer,
     IReportsContainer,)
-from waeup.kofa.reports import (
+from waeup.ikoba.reports import (
     Report, ReportGenerator, get_generators, report_job, AsyncReportJob,
     ReportJobContainer, ReportsContainer, ReportsContainerPlugin)
-from waeup.kofa.testing import FakeJob, FakeJobManager, FunctionalLayer
-from waeup.kofa.tests.test_async import FunctionalAsyncTestCase
+from waeup.ikoba.testing import FakeJob, FakeJobManager, FunctionalLayer
+from waeup.ikoba.tests.test_async import FunctionalAsyncTestCase
 
 class FakeReportGenerator(ReportGenerator):
@@ -77,5 +77,5 @@
 class ReportGeneratorTest(unittest.TestCase):
     def setUp(self):
-        grok.testing.grok('waeup.kofa.reports') # register utils
+        grok.testing.grok('waeup.ikoba.reports') # register utils
 
     def test_iface(self):
@@ -117,5 +117,5 @@
 
     def setUp(self):
-        grok.testing.grok('waeup.kofa.reports') # register utils
+        grok.testing.grok('waeup.ikoba.reports') # register utils
         super(HelpersTests, self).setUp()
         return
@@ -361,5 +361,5 @@
     def create_logger(self):
         # create a logger suitable for local tests.
-        test_logger = logging.getLogger('waeup.kofa.reports.testlogger')
+        test_logger = logging.getLogger('waeup.ikoba.reports.testlogger')
         log = StringIO()
         handler = logging.StreamHandler(log)
@@ -393,12 +393,12 @@
         # make sure we fullfill the promised interfaces
         obj = ReportsContainerPlugin()
-        verifyClass(IKofaPluggable, ReportsContainerPlugin)
-        verifyObject(IKofaPluggable, obj)
+        verifyClass(IIkobaPluggable, ReportsContainerPlugin)
+        verifyObject(IIkobaPluggable, obj)
         return
 
     def test_get_as_utility(self):
         # make sure we can get the plugin as utility
-        grok.testing.grok('waeup.kofa.reports')
-        util = getUtility(IKofaPluggable, name='reports')
+        grok.testing.grok('waeup.ikoba.reports')
+        util = getUtility(IIkobaPluggable, name='reports')
         self.assertTrue(util is not None)
         return
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_smtp.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_smtp.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_smtp.py	(revision 11949)
@@ -27,10 +27,10 @@
 from zope.component.hooks import setSite
 from zope.sendmail.interfaces import IMailDelivery
-from waeup.kofa.app import University
-from waeup.kofa.interfaces import IMailService
-from waeup.kofa.smtp import (
+from waeup.ikoba.app import University
+from waeup.ikoba.interfaces import IMailService
+from waeup.ikoba.smtp import (
     encode_header_item, encode_address, encode_body, FakeSMTPDelivery,
     send_mail)
-from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+from waeup.ikoba.testing import FunctionalLayer, FunctionalTestCase
 
 #
@@ -370,5 +370,5 @@
             'test program', 'no-reply@waeup.org',
             'test mail receiver', EXTERNAL_MAIL_RECEIVER,
-            'Test Mail from WAeUP Kofa',
+            'Test Mail from WAeUP Ikoba',
             'Hi from test mailer!\n\nRegards,\nTest Programme\n'
             )
@@ -388,5 +388,5 @@
             'test mail receiver',
             '%s, %s' % (EXTERNAL_MAIL_RECEIVER, EXTERNAL_MAIL_RECEIVER),
-            'Test Mail from WAeUP Kofa',
+            'Test Mail from WAeUP Ikoba',
             'Hi from test mailer!\n\nRegards,\nTest Programme\n'
             )
@@ -405,5 +405,5 @@
             'test program', 'no-reply@waeup.org',
             'test mail receiver', EXTERNAL_MAIL_RECEIVER,
-            'Test Mail from WAeUP Kofa',
+            'Test Mail from WAeUP Ikoba',
             'Hi from test mailer!\n\nRegards,\nTest Programme\n'
             )
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_startup.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_startup.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_startup.py	(revision 11949)
@@ -5,5 +5,5 @@
 import unittest
 from zope.app.wsgi import WSGIPublisherApplication
-from waeup.kofa.startup import env_app_factory, env_debug_app_factory
+from waeup.ikoba.startup import env_app_factory, env_debug_app_factory
 
 ZOPE_CONF_TEMPL = '''
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_async.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_async.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_async.py	(revision 11949)
@@ -1,3 +1,3 @@
 # Tests for the async module of waeup.kofa
 import os
 import re
@@ -16,9 +16,9 @@
 from zope.site.folder import rootFolder
 from zope.site.testing import createSiteManager
-from waeup.kofa.interfaces import (
+from waeup.ikoba.interfaces import (
     WAEUP_KEY, IProgressable, IJobManager, IJobContainer
     )
-from waeup.kofa.testing import FunctionalTestCase, FunctionalLayer
-from waeup.kofa.async import (
+from waeup.ikoba.testing import FunctionalTestCase, FunctionalLayer
+from waeup.ikoba.async import (
     get_job_id, AsyncJob, ProgressableJob, JobManager, JobContainer,
     JobManagerTraverser, JobContainerInstaller,
@@ -1,3 +1,3 @@
-# Tests for the async module of waeup.kofa
+# Tests for the async module of waeup.ikoba
 import os
 import re
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_doctests.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_doctests.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_doctests.py	(revision 11949)
@@ -16,7 +16,7 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """Register doctests for waeup.kofa.
 """
-from waeup.kofa.testing import get_doctest_suite
+from waeup.ikoba.testing import get_doctest_suite
 
 def test_suite():
@@ -16,7 +16,7 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Register doctests for waeup.kofa.
+"""Register doctests for waeup.ikoba.
 """
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_schoolgrades.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_schoolgrades.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_schoolgrades.py	(revision 11949)
@@ -4,14 +4,14 @@
 from zope.interface.verify import verifyObject, verifyClass
 from zope.schema.interfaces import ConstraintNotSatisfied
-from waeup.kofa.interfaces import IResultEntry, IResultEntryField, IKofaUtils
-from waeup.kofa.schoolgrades import ResultEntry, ResultEntryField
-from waeup.kofa.utils.utils import KofaUtils
+from waeup.ikoba.interfaces import IResultEntry, IResultEntryField, IIkobaUtils
+from waeup.ikoba.schoolgrades import ResultEntry, ResultEntryField
+from waeup.ikoba.utils.utils import IkobaUtils
 
 class ResultEntryTests(unittest.TestCase):
 
     def setUp(self):
-        self.utils = KofaUtils()
+        self.utils = IkobaUtils()
         self.gsm = getGlobalSiteManager()
-        self.gsm.registerUtility(self.utils, IKofaUtils)
+        self.gsm.registerUtility(self.utils, IIkobaUtils)
         self.valid_subj = self.utils.EXAM_SUBJECTS_DICT.keys()[0]
         self.valid_grade = self.utils.EXAM_GRADES[0][0]
@@ -40,5 +40,5 @@
 
     def test_illegal_value(self):
         # we do not accept values not stored in KofaUtils
         item = ResultEntry()
         self.assertRaises(
@@ -40,5 +40,5 @@
 
     def test_illegal_value(self):
-        # we do not accept values not stored in KofaUtils
+        # we do not accept values not stored in IkobaUtils
         item = ResultEntry()
         self.assertRaises(
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_sourcefactory.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_sourcefactory.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_sourcefactory.py	(revision 11949)
@@ -1,5 +1,5 @@
 ## Tests for waeup.kofa.sourcefactory.
 import unittest
-from waeup.kofa.sourcefactory import SmartBasicContextualSourceFactory
+from waeup.ikoba.sourcefactory import SmartBasicContextualSourceFactory
 
 class MyContext(object):
@@ -1,5 +1,5 @@
-## Tests for waeup.kofa.sourcefactory.
+## Tests for waeup.ikoba.sourcefactory.
 import unittest
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_waeup.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/tests/test_waeup.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_waeup.py	(revision 11949)
@@ -17,5 +17,5 @@
 ##
 """
-Test setup for the waeup.kofa package.
+Test setup for the waeup.ikoba package.
 """
 import grok
@@ -23,5 +23,5 @@
 import zope.component.eventtesting
 from zope.testing import renormalizing
-from waeup.kofa.testing import FunctionalLayer
+from waeup.ikoba.testing import FunctionalLayer
 
 def setUpZope(test):
@@ -32,6 +32,6 @@
         ])
 
 # Register all tests in the waeup.kofa package
 test_suite = grok.testing.register_all_tests(
-    'waeup.kofa', checker=checker, usetup=setUpZope,
+    'waeup.ikoba', checker=checker, usetup=setUpZope,
     layer=FunctionalLayer)
@@ -32,6 +32,6 @@
         ])
 
-# Register all tests in the waeup.kofa package
+# Register all tests in the waeup.ikoba package
 test_suite = grok.testing.register_all_tests(
